@@ -2,7 +2,7 @@
  * librfc1924: Function libary for conversions
  *               defined in RFC 1924
  *
- * Version:		$Id: librfc1924.c,v 0.16 2001/03/13 $
+ * Version:		$Id: librfc1924.c,v 1.2 2001/10/09 07:03:10 peter Exp $
  * 
  * Author:		Peter Bieringer <pb@bieringer.de>
  *
@@ -15,6 +15,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include "ipv6calc.h"
+#include "libipv6addr.h"
 
 /*
  * Base 85 (RFC 1924) encodings of IPv6 addresses
@@ -258,7 +259,7 @@ static char *pk85(bitvec bv) {
  */
 
 int ipv6addrstruct_to_base85(ipv6calc_ipv6addr *ipv6addrp, char *resultstring) {
-	int retval = 1, nbit, nword;
+	int retval = 1, nbit, ndword;
 	unsigned int mask;
 	bitvec bv;
 
@@ -266,13 +267,13 @@ int ipv6addrstruct_to_base85(ipv6calc_ipv6addr *ipv6addrp, char *resultstring) {
 	bv = zbv();
 
 	for (nbit = 0; nbit <= 127; nbit++) {
-		/* calculate word (16 bit) - matches with addr6p[]*/
-		nword = (nbit & 0x70) >> 4;
+		/* calculate dword (32 bit) */
+		ndword = (nbit & 0x60) >> 5;
 		
 		/* calculate mask */
-		mask = 0x8000 >> ((nbit & 0x0f));
+		mask = 0x80000000 >> ((nbit & 0x01f));
 		
-		if ( ipv6addrp->addr6[nword] & mask ) {
+		if ( ipv6addr_getdword(ipv6addrp, ndword) & mask ) {
 			bv.b[nbit] = 1;
 		};
 	};
@@ -293,7 +294,7 @@ int ipv6addrstruct_to_base85(ipv6calc_ipv6addr *ipv6addrp, char *resultstring) {
  */
 
 int base85_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp) {
-	int retval = 1, nbit, nword;
+	int retval = 1, nbit, ndword;
 	size_t cnt;
 	unsigned int mask;
 	bitvec bv;
@@ -317,21 +318,23 @@ int base85_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6
 	bv = unpk85(addrstring);
 
 	/* Clear IPv6 address structure */
-	for (nword = 0; nword <= 7; nword++) {
-		ipv6addrp->addr6[nword] = 0;
-	};
+	ipv6addr_clear(ipv6addrp);
+
 	/* fill IPv6 address structure */
 	for (nbit = 0; nbit <= 127; nbit++) {
 		/* calculate word (16 bit) - matches with addr6p[]*/
-		nword = (nbit & 0x70) >> 4;
+		ndword = (nbit & 0x60) >> 5;
 		
 		/* calculate mask */
-		mask = 0x8000 >> ((nbit & 0x0f));
+		mask = 0x80000000 >> ((nbit & 0x1f));
 	
 		if ( bv.b[nbit] == 1 ) {
-			ipv6addrp->addr6[nword] = ipv6addrp->addr6[nword] | mask;
+			ipv6addr_setdword(ipv6addrp, ndword, ipv6addr_getdword(ipv6addrp, ndword) | mask);
 		};
 	};
+	
+	/* Get scope */
+	ipv6addrp->scope = ipv6addr_gettype(ipv6addrp);
 
    	retval = 0;	
 	return (retval);
